using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Akadia
{
	namespace BaseObjects
	{
		public class BaseEditDialog : System.Windows.Forms.Form
		{
			// These Objects cannot be changed in the derived Forms
			private System.Windows.Forms.Button btnOK;
			private System.Windows.Forms.Button btnReset;
			private System.Windows.Forms.Button btnCancel;

			// These Objects can be changed in the derived Forms
			protected System.Windows.Forms.Panel panel1;

			// Designer needed
			private System.ComponentModel.Container components = null;

			// Create visual components
			public BaseEditDialog()
			{
				InitializeComponent();
			}

			// Cleanup
			protected override void Dispose( bool disposing )
			{
				if( disposing )
				{
					if(components != null)
					{
						components.Dispose();
					}
				}
				base.Dispose( disposing );
			}

		#region Windows Form Designer generated code
			/// <summary>
			/// Required method for Designer support - do not modify
			/// the contents of this method with the code editor.
			/// </summary>
			private void InitializeComponent()
			{
				this.btnOK = new System.Windows.Forms.Button();
				this.btnReset = new System.Windows.Forms.Button();
				this.btnCancel = new System.Windows.Forms.Button();
				this.panel1 = new System.Windows.Forms.Panel();
				this.SuspendLayout();
				// 
				// btnOK
				// 
				this.btnOK.DialogResult = System.Windows.Forms.DialogResult.OK;
				this.btnOK.Location = new System.Drawing.Point(40, 234);
				this.btnOK.Name = "btnOK";
				this.btnOK.TabIndex = 0;
				this.btnOK.Text = "&OK";
				// 
				// btnReset
				// 
				this.btnReset.Location = new System.Drawing.Point(137, 234);
				this.btnReset.Name = "btnReset";
				this.btnReset.TabIndex = 1;
				this.btnReset.Text = "&Reset";
				this.btnReset.Click += new System.EventHandler(this.btnReset_Click);
				// 
				// btnCancel
				// 
				this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
				this.btnCancel.Location = new System.Drawing.Point(234, 234);
				this.btnCancel.Name = "btnCancel";
				this.btnCancel.TabIndex = 2;
				this.btnCancel.Text = "&Cancel";
				// 
				// panel1
				// 
				this.panel1.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
				this.panel1.Location = new System.Drawing.Point(10, 13);
				this.panel1.Name = "panel1";
				this.panel1.Size = new System.Drawing.Size(328, 202);
				this.panel1.TabIndex = 3;
				// 
				// BaseEditDialog
				// 
				this.AcceptButton = this.btnOK;
				this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
				this.CancelButton = this.btnCancel;
				this.ClientSize = new System.Drawing.Size(349, 273);
				this.Controls.AddRange(new System.Windows.Forms.Control[] {
																			  this.panel1,
																			  this.btnCancel,
																			  this.btnReset,
																			  this.btnOK});
				this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
				this.MaximizeBox = false;
				this.MinimizeBox = false;
				this.Name = "BaseEditDialog";
				this.ShowInTaskbar = false;
				this.Text = "BaseEditDialog";
				this.ResumeLayout(false);

			}
		#endregion

			// Derived Forms MUST override this method
			protected virtual void ResetSettings()
			{
				// Code logic in derived Form
			}

			// Derived Forms MUST override this method
			protected virtual bool SaveSettings()
			{
				// Code logic in derived Form
				return true;
			}

			// The Form class provides a Closing event that occurs
			// whenever the form is about to close. The protected
			// OnClosing method is invoked whenever the Close method
			// is called, and it in turn raises the Closing event by
			// invoking any registered event handlers.
			//
			// If Cancel is set to TRUE, then the close
			// operation is cancelled and the application will
			// continute to run.
			//
			// If Cancel is set to FALSE, then the close
			// operation is not cancelled and the application will
			// exit.
			protected override void OnClosing(CancelEventArgs e)
			{
				// If user clicked the OK button, make sure to
				// save the content. This must be done in the
				// SaveSettings() method in the derived Form.
				if (!e.Cancel && (this.DialogResult == DialogResult.OK))
				{
					// If SaveSettings() is OK (TRUE), then e.Cancel
					// will be FALSE, therefore the application will be exit.
					e.Cancel = !SaveSettings();
				}

				// Make sure any Closing event handler for the
				// form are called before the application exits.
				base.OnClosing(e);
			}

			// Event for Reset Button Click
			private void btnReset_Click(object sender, System.EventArgs e)
			{
				// Call ResetSettings()in the derived Form
				ResetSettings();
			}
		}
	}
}
